@@ -15,6 +15,16 @@ def test_validate_srdf():
   print(result.output)
   assert 'ERROR' not in result.output
 
+def test_convert_openms():
+  """
+    Test the default behaviour of the vcf-to-proteindb tool
+    :return:
+    """
+  runner = CliRunner()
+  result = runner.invoke(cli, ['convert-openms', '-t2', '-l', '-s','testdata/sdrf.tsv'])
+  print('convert to openms' + result.output)
+  assert 'ERROR' not in result.output
+
 
 def test_bioontologies():
   keyword = 'human'
@@ -38,3 +48,4 @@ def test_bioontologies():
 if __name__ == '__main__':
   test_bioontologies()
   test_validate_srdf()
+  test_convert_openms()
